from django import template
from django.conf import settings
from django.db import models

from django_markdown.utils import markdown

register = template.Library()

from ..models import Blurb

@register.filter
def get_blurb (bkey):
  ret = None
  
  try:
    b = Blurb.objects.get(slug=bkey)
    
  except models.ObjectDoesNotExist:
    ret = None
    
  else:
    if b.content:
      ret = markdown(b.content, extensions=settings.MARKDOWN_EXTENSIONS)
      
  if ret is None:
    ret = 'No content found for {}'.format(bkey)
    
  return ret
  


# -*- coding: utf-8 -*-
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding field 'Event.url'
        db.add_column(u'calendar_event', 'url',
                      self.gf('django.db.models.fields.URLField')(max_length=200, null=True, blank=True),
                      keep_default=False)


    def backwards(self, orm):
        # Deleting field 'Event.url'
        db.delete_column(u'calendar_event', 'url')


    models = {
        u'calendar.category': {
            'Meta': {'ordering': "('slug',)", 'object_name': 'Category'},
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'slug': ('django.db.models.fields.SlugField', [], {'unique': 'True', 'max_length': '200'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        u'calendar.event': {
            'Meta': {'ordering': "('start_dt', '-all_day', 'end_dt')", 'object_name': 'Event'},
            'all_day': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'body': ('django.db.models.fields.TextField', [], {}),
            'categories': ('django.db.models.fields.related.ManyToManyField', [], {'symmetrical': 'False', 'to': u"orm['calendar.Category']", 'null': 'True', 'blank': 'True'}),
            'end_dt': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'image': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['kitchen_sink.Image']", 'null': 'True', 'blank': 'True'}),
            'imageset': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['kitchen_sink.ImageSet']", 'null': 'True', 'blank': 'True'}),
            'series': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['calendar.Series']", 'null': 'True', 'blank': 'True'}),
            'start_dt': ('django.db.models.fields.DateTimeField', [], {}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'url': ('django.db.models.fields.URLField', [], {'max_length': '200', 'null': 'True', 'blank': 'True'})
        },
        u'calendar.series': {
            'Meta': {'object_name': 'Series'},
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '255'})
        },
        u'kitchen_sink.image': {
            'Meta': {'ordering': "('title',)", 'object_name': 'Image'},
            'caption': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'caption_url': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'credit': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'credit_url': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'file': ('django.db.models.fields.files.ImageField', [], {'max_length': '100'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '255'})
        },
        u'kitchen_sink.imageset': {
            'Meta': {'ordering': "('title',)", 'object_name': 'ImageSet'},
            'captype': ('django.db.models.fields.CharField', [], {'default': "'override'", 'max_length': '10'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '255'})
        }
    }

    complete_apps = ['calendar']


import os
import re

from django import template

register = template.Library()

@register.filter
def get_file_format (post, ftype):
  return post.mediafile_set.get(ext__ext=ftype)
  
@register.filter
def http_url (url):
  return url.replace('https://', 'http://')
  
@register.filter
def filename (path):
  return os.path.basename(path)
  
@register.filter
def format_video_size (embed, size):
    size = size.split('x')
    
    embed = re.sub('width="\d+"', 'width="%s"' % size[0], embed, flags=re.I)
    embed = re.sub("width='\d+'", "width='%s'" % size[0], embed, flags=re.I)
    
    embed = re.sub('height="\d+"', 'height="%s"' % size[1], embed, flags=re.I)
    embed = re.sub("height='\d+'", "height='%s'" % size[1], embed, flags=re.I)
    
    return embed
    


from django.contrib import admin
from django.db import models
from django import forms

from pizza.kitchen_sink.widgets import RichText
from pizza.kitchen_sink.admin import AdminMixin

from .models import Blog, Category, Post, FileFormat, MediaFile

import mpeg1audio

class BlogAdmin (AdminMixin, admin.ModelAdmin):
  list_display = ('title', 'slug', 'podcast', '_sites')
  search_fields = ('title', 'slug')
  list_filter = ('sites', 'podcast')
  filter_horizontal = ('sites', 'authors', 'formats')
  raw_id_fields = ('image',)
  autocomplete_lookup_fields = {
    'fk': ['image',],
  }
  
def merge_cats (modeladmin, request, queryset):
  if queryset.count() > 1:
    cat = queryset[0]
    for c in queryset[1:]:
      if hasattr(c, 'post_set'):
        for post in c.post_set.all():
          post.categories.remove(c)
          post.categories.add(cat)
          
      if hasattr(c, 'event_set'):
        for post in c.event_set.all():
          post.categories.remove(c)
          post.categories.add(cat)
          
    for c in queryset[1:]:
      c.delete()
      
merge_cats.short_description = "Merge Categories"

class CategoryAdmin (AdminMixin, admin.ModelAdmin):
  list_display = ('title', 'slug', 'posts')
  search_fields = ('title', 'slug')
  actions = (merge_cats,)
  
  def posts (self, obj):
    return obj.post_set.all().count()
    
class MediaFileInline (admin.TabularInline):
  model = MediaFile
  
class PostForm (forms.ModelForm):
  class Meta:
    model = Post
    fields = ('blog', 'title', 'slug', 'authors', 'categories', 'image', 'imageset', 'body',
              'audio_embed', 'video_embed', 'publish')
    widgets = {
      'body': RichText
    }
    
class PostAdmin (AdminMixin, admin.ModelAdmin):
  list_display = ('title', 'publish', 'slug', 'blog', 'Categories')
  search_fields = ('title', 'slug', 'blog')
  list_filter = ('blog', 'categories')
  date_hierarchy = 'publish'
  
  filter_horizontal = ('categories', 'authors')
  
  raw_id_fields = ('blog', 'image', 'imageset')
  autocomplete_lookup_fields = {
    'fk': ['blog', 'image', 'imageset'],
  }
  
  form = PostForm
  inlines = (MediaFileInline,)
  
  def save_formset (self, request, form, formset, change):
    super(PostAdmin, self).save_formset(request, form, formset, change)
    
    for f in formset:
      if 'file' in f.cleaned_data and f.cleaned_data['file']:
        if f.cleaned_data['ext'].ext.lower() == 'mp3':
          f.cleaned_data['file'].seek(0)
          try:
            mp3 = mpeg1audio.MPEGAudio(f.cleaned_data['file'])
            
          except mpeg1audio.MPEGAudioHeaderException:
            pass
            
          else:
            f.instance.duration = mp3.duration
            f.instance.save()
            
          f.cleaned_data['file'].seek(0)
          
class FileFormatAdmin (AdminMixin, admin.ModelAdmin):
  list_display = ('title', 'ext', 'mtype')
  
admin.site.register(Post, PostAdmin)
admin.site.register(Category, CategoryAdmin)
admin.site.register(Blog, BlogAdmin)
admin.site.register(FileFormat, FileFormatAdmin)



import json
import types

from django.core.management.base import BaseCommand, CommandError
from django.contrib.sites.models import Site
from django.utils import timezone

from pizza.kitchen_sink.models import Page, Version, Image, Inline

def yes_no (message):
  while 1:
    ans = raw_input(message + ' [y/n]: ')
    if ans.lower() in ['y', 'n']:
      if ans.lower() == 'y':
        return True
        
      break
      
  return False
  
def choose_page (page, pages):
  choices = {'0': None}
  print "Choose a page to overwrite for {} - {}".format(page['url'], page['sites_list'])
  print "0: Create New Page"
  
  count = 1
  for p in pages:
    choices[str(count)] = p
    sites = ", ".join(p.sites.all().values_list('name', flat=True))
    print "{}: {} - {}".format(count, p.url, sites)
    count += 1
    
  while 1:
    ans = raw_input('Choice: ')
    if ans in choices.keys():
      return choices[ans]
      
def new_version (page, **kwargs):
  v = kwargs['version']
  if v:
    version = Version(page=page,
      title=v['title'],
      keywords=v['keywords'],
      desc=v['description'],
    )
    
    if kwargs['published']:
      version.publish = timezone.now()
      
    del v['title']
    del v['keywords']
    del v['description']
    
    for key, value in v.items():
      if type(value) in [types.ListType, types.TupleType]:
        cnt = 0
        for item in value:
          inline = Inline(page=page, icnt=cnt)
          inline.save()
          item['iid'] = inline.id
          cnt += 1
          
    version.set_content(v)
    
    return version
    
  return None
  
def convert_images (vdict, create_images):
  for key, value in vdict.items():
    if type(value) is types.DictType:
      images = Image.objects.filter(file=value['name'])
      image = None
      
      if images.count() > 0:
        image = images[0]
        
      elif create_images:
        image = Image(file=value['name'])
        #todo check if image exists, if not download and add to storage
        
      if image:
        image.credit = value['credit']
        image.title = value['title']
        image.credit_url = value['credit_url']
        image.caption = value['caption']
        image.caption_url = value['caption_url']
        image.save()
        vdict[key] = image.id
        
      else:
        vdict[key] = image
        
    elif type(value) in [types.ListType, types.TupleType]:
      items = []
      for item in value:
        item = convert_images(item, create_images)
        items.append(item)
        
      vdict[key] = items
      
  return vdict
  
class Command (BaseCommand):
  args = '<json_file json_file ...>'
  help = 'Closes the specified poll for voting'
  
  def handle (self, *args, **options):
    create_sites = yes_no('Create Sites if not found?')
    create_images = yes_no('Create and download images?')
    
    for jfile in args:
      print 'Importing', jfile, '...'
      fh = open(jfile, 'r')
      data = json.loads(fh.read())
      fh.close()
      
      sites = {}
      for site in data['sites']:
        obj, created = Site.objects.get_or_create(name=site['name'], defaults={'domain': site['domain']})
        if created:
          if create_sites:
            print 'Created Site:', obj.name
            obj.save()
            
          else:
            obj = None
            
        sites[site['id']] = obj
        
      for export in data['exports']:
        export['sites_list'] = ", ".join([sites[s].name for s in export['sites']])
        
        pages = Page.objects.filter(url=export['url'])
        page = None
        if pages.count() == 1:
          page = pages[0]
          
        elif pages.count() > 1:
          page = choose_page(export, pages)
          
        if page is None:
          page = Page(url=export['url'], tpl='narf')
          
        print export['url'], '-', export['sites_list']
        page.tpl = export['tpl']
        page.save()
        page.sites.clear()
        for s in export['sites']:
          page.sites.add(sites[s])
          
        export['version'] = convert_images(export['version'], create_images)
        version = new_version(page, **export)
        if version:
          version.save()
          
      print 'Import Complete\n'
      


from django import forms
from django.conf import settings
from django.utils.safestring import mark_safe
from django.core.urlresolvers import reverse

from django_markdown.widgets import MarkdownWidget as RichText

class HiddenViewInput (forms.HiddenInput):
  def render (self, name, value, attrs=None):
    ret = super(HiddenViewInput, self).render(name, value, attrs=attrs)
    if value:
      ret = '<strong style="display: block; padding-top: 4px;">' + str(value) + '</strong>' + ret
      
    return mark_safe(ret)
    
class RichTextOld (forms.Textarea):
  def render (self, name, value, attrs=None):
    ret = super(RichText, self).render(name, value, attrs=attrs)
    ret = ret.replace('<textarea ', '<textarea class="pizza_editor" ')
    
    return mark_safe(ret)
    
  class Media:
    css = {'all': ('ks/css/pizza_editor.css',)}
    
    js = (
      'ks/ckeditor/ckeditor.js',
      'ks/js/pizza_editor.js',
    )
    